@@ -19,8 +19,9 @@
  */
 
 #include <glom/box_withbuttons.h>
-#include <glom/application.h> //Application.
+#include <glom/appwindow.h> //AppWindow.
 #include <glom/utils_ui.h>
+#include <gtkmm/stock.h>
 #include <libglom/appstate.h>
 //#include <libgnomeui/gnome-app-helper.h>
 
@@ -30,7 +31,8 @@ namespace Glom
 {
 
 Box_WithButtons::Box_WithButtons()
-: m_Box_Buttons(false, Utils::DEFAULT_SPACING_SMALL),
+: Gtk::Box(Gtk::ORIENTATION_VERTICAL),
+  m_Box_Buttons(Gtk::ORIENTATION_HORIZONTAL, Utils::DEFAULT_SPACING_SMALL),
   m_Button_Cancel(Gtk::Stock::CANCEL)
 {
   //m_pDocument = 0;
@@ -43,8 +45,8 @@ Box_WithButtons::Box_WithButtons()
 }
 
 Box_WithButtons::Box_WithButtons(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
-: Gtk::VBox(cobject),
-  m_Box_Buttons(false, Utils::DEFAULT_SPACING_SMALL),
+: Gtk::Box(cobject),
+  m_Box_Buttons(Gtk::ORIENTATION_HORIZONTAL, Utils::DEFAULT_SPACING_SMALL),
   m_Button_Cancel(Gtk::Stock::CANCEL)
 {
   //m_pDocument = 0;
@@ -57,8 +59,8 @@ Box_WithButtons::Box_WithButtons(BaseObjectType* cobject, const Glib::RefPtr<Gtk
 }
 
 Box_WithButtons::Box_WithButtons(BaseObjectType* cobject)
-: Gtk::VBox(cobject),
-  m_Box_Buttons(false, Utils::DEFAULT_SPACING_SMALL),
+: Gtk::Box(cobject),
+  m_Box_Buttons(Gtk::ORIENTATION_HORIZONTAL, Utils::DEFAULT_SPACING_SMALL),
   m_Button_Cancel(Gtk::Stock::CANCEL)
 {
 }
