@@ -22,7 +22,7 @@
 #include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
 
 #include <glom/frame_glom.h>
-#include <glom/application.h>
+#include <glom/appwindow.h>
 #include <glom/import_csv/dialog_import_csv.h>
 #include <glom/import_csv/dialog_import_csv_progress.h>
 #include <libglom/appstate.h>
@@ -154,6 +154,8 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
   m_Notebook_Find.signal_find_criteria.connect(sigc::mem_fun(*this, &Frame_Glom::on_notebook_find_criteria));
   m_Notebook_Find.show();
   m_Notebook_Data.signal_record_details_requested().connect(sigc::mem_fun(*this, &Frame_Glom::on_notebook_data_record_details_requested));
+  m_Notebook_Data.signal_record_selection_changed().connect(sigc::mem_fun(*this,
+    &Frame_Glom::on_notebook_data_record_selection_changed));
   m_Notebook_Data.signal_switch_page().connect(sigc::mem_fun(*this, &Frame_Glom::on_notebook_data_switch_page));
   m_Notebook_Data.show();
 
@@ -261,7 +263,7 @@ void Frame_Glom::set_mode_widget(Gtk::Widget& widget)
   //Trying to remove all of them leads to warnings,
   //and I don't see a way to get a list of children.
 
-  Application* pApp = dynamic_cast<Application*>(get_app_window());
+  AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
   if(pApp)
   {
     //Glib::RefPtr<Gtk::UIManager> ui_manager = pApp->get_ui_manager();
@@ -332,7 +334,7 @@ void Frame_Glom::show_table_refresh()
 
 void Frame_Glom::show_table_allow_empty(const Glib::ustring& table_name, const Gnome::Gda::Value& primary_key_value_for_details)
 {
-  Application* pApp = dynamic_cast<Application*>(get_app_window());
+  AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
 
   //This can take quite a long time, so we show the busy cursor while it's working:
   BusyCursor busy_cursor(pApp);
@@ -392,7 +394,12 @@ void Frame_Glom::show_table_allow_empty(const Glib::ustring& table_name, const G
           type_vecLayoutFields layout_fields;
           layout_fields.push_back(layout_item_temp);
           Glib::RefPtr<Gnome::Gda::SqlBuilder> sql_query_without_sort = Utils::build_sql_select_with_where_clause(found_set.m_table_name, layout_fields, found_set.m_where_clause, found_set.m_extra_join, type_sort_clause());
-          const int count = DbUtils::count_rows_returned_by(sql_query_without_sort);
+
+          const Privileges table_privs = Privs::get_current_privs(found_set.m_table_name);
+          int count = 0;
+          if(table_privs.m_view) //Avoid the query if the user does not have view rights, because it would fail.
+            count = DbUtils::count_rows_returned_by(sql_query_without_sort);
+            
           if(count < 10000) //Arbitrary large number.
             found_set.m_sort_clause.push_back( type_pair_sort_field(layout_item_sort, true /* ascending */) );
         }
@@ -464,7 +471,9 @@ void Frame_Glom::on_menu_developer_developer(const Glib::RefPtr<Gtk::RadioAction
       bool test = true;
 
       if(sharedconnection && sharedconnection->get_gda_connection()->supports_feature(Gnome::Gda::CONNECTION_FEATURE_USERS))
-        Privs::get_user_is_in_group(connection_pool->get_user(), GLOM_STANDARD_GROUP_NAME_DEVELOPER);
+      {
+        test = Privs::get_user_is_in_group(connection_pool->get_user(), GLOM_STANDARD_GROUP_NAME_DEVELOPER);
+      }
 
       if(test)
       {
@@ -844,7 +853,7 @@ void Frame_Glom::on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>
         const bool initial_password_provided = connection_request_initial_password(user, password);
         bool added = false;
         if(initial_password_provided)
-          added = add_user(user, password, GLOM_STANDARD_GROUP_NAME_DEVELOPER);
+          added = DbUtils::add_user(document, user, password, GLOM_STANDARD_GROUP_NAME_DEVELOPER);
 
         if(initial_password_provided && added)
         {
@@ -894,7 +903,7 @@ void Frame_Glom::on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>
           const bool reowned = set_database_owner_user(connectionpool->get_user());
           bool removed = false;
           if(reowned)
-            removed = remove_user(default_user);
+            removed = DbUtils::remove_user(default_user);
 
           if(!removed)
           {
@@ -902,6 +911,12 @@ void Frame_Glom::on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>
             //Try to revoke it instead.
             //TODO: Discover how to make remove_user() succeed.
             disabled = disable_user(default_user);
+            if(disabled)
+            {
+              //This message should be reassuring if the user sees a previous error
+              //about the default user not being removed.
+              std::cout << G_STRFUNC << ": The default user could not be removed, but it has been disabled." << std::endl;
+            }
           }
 
           if(!reowned || !(removed || disabled))
@@ -942,7 +957,7 @@ void Frame_Glom::on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>
         Glib::ustring default_password;
         const Glib::ustring default_user = Privs::get_default_developer_user_name(default_password);
 
-        const bool added = add_user(default_user, default_password, GLOM_STANDARD_GROUP_NAME_DEVELOPER);
+        const bool added = DbUtils::add_user(document, default_user, default_password, GLOM_STANDARD_GROUP_NAME_DEVELOPER);
         if(!added)
         {
            shared = true;
@@ -990,7 +1005,7 @@ void Frame_Glom::on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>
   }
 
   //Update the UI:
-  Application* pApp = dynamic_cast<Application*>(get_app_window());
+  AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
   if(pApp)
   {
     pApp->update_network_shared_ui();
@@ -1167,7 +1182,7 @@ void Frame_Glom::on_dialog_add_related_table_response(int response)
       sharedptr<Relationship> relationship = sharedptr<Relationship>::create();
 
       relationship->set_name(relationship_name);
-      relationship->set_title(Utils::title_from_string(relationship_name), Application::get_current_locale());
+      relationship->set_title(Utils::title_from_string(relationship_name), AppWindow::get_current_locale());
       relationship->set_from_table(m_table_name);
       relationship->set_from_field(from_key_name);
       relationship->set_to_table(table_name);
@@ -1314,7 +1329,7 @@ void Frame_Glom::on_notebook_find_criteria(const Gnome::Gda::SqlExpr& where_clau
 {
   //std::cout << "debug: " << G_STRFUNC << ": " << where_clause << std::endl;
 
-  Application* pApp = dynamic_cast<Application*>(get_app_window());
+  AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
   if(pApp)
   {
     bool records_found = false;
@@ -1365,7 +1380,7 @@ void Frame_Glom::show_table_title()
     return;
 
   //Show the table title:
-  Glib::ustring table_label = document->get_table_title(m_table_name, Application::get_current_locale());
+  Glib::ustring table_label = document->get_table_title(m_table_name, AppWindow::get_current_locale());
   if(!table_label.empty())
   {
     if(document->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
@@ -1393,6 +1408,12 @@ void Frame_Glom::update_table_in_document_from_database()
 
   //Get the fields information from the database:
   DbUtils::type_vec_fields fieldsDatabase = DbUtils::get_fields_for_table_from_database(m_table_name);
+  if(fieldsDatabase.empty())
+  {
+    std::cerr << G_STRFUNC << ": Could not get the list of fields for table=" << m_table_name <<
+      " from the database. This might be due to insufficient database user rights." << 
+      " Falling back to the field details in the document." << std::endl;
+  }
 
   Document* pDoc = dynamic_cast<const Document*>(get_document());
   if(pDoc)
@@ -1448,25 +1469,28 @@ void Frame_Glom::update_table_in_document_from_database()
 
     //Remove fields that are no longer in the database:
     //TODO_performance: This is incredibly inefficient - but it's difficut to erase() items while iterating over them.
-    type_vec_fields fieldsActual;
-    for(type_vec_fields::const_iterator iter = fieldsDocument.begin(); iter != fieldsDocument.end(); ++iter)
+    if(!fieldsDatabase.empty()) //Do not do this if getting the fields from the database failed completely, probably due to permissions.
     {
-      sharedptr<Field> field = *iter;
+      type_vec_fields fieldsActual;
+      for(type_vec_fields::const_iterator iter = fieldsDocument.begin(); iter != fieldsDocument.end(); ++iter)
+      {
+        sharedptr<Field> field = *iter;
 
-      //Check whether it's in the database:
-      type_vec_fields::iterator iterFindDatabase = std::find_if( fieldsDatabase.begin(), fieldsDatabase.end(), predicate_FieldHasName<Field>( field->get_name() ) );
-      if(iterFindDatabase != fieldsDatabase.end()) //If it was found
-      {
-        fieldsActual.push_back(field);
-      }
-      else
-      {
-        document_must_be_updated = true; //Something changed.
+        //Check whether it's in the database:
+        type_vec_fields::iterator iterFindDatabase = std::find_if( fieldsDatabase.begin(), fieldsDatabase.end(), predicate_FieldHasName<Field>( field->get_name() ) );
+        if(iterFindDatabase != fieldsDatabase.end()) //If it was found
+        {
+          fieldsActual.push_back(field);
+        }
+        else
+        {
+          document_must_be_updated = true; //Something changed.
+        }
       }
+
+      if(document_must_be_updated)
+        pDoc->set_table_fields(m_table_name, fieldsActual);
     }
-
-    if(document_must_be_updated)
-      pDoc->set_table_fields(m_table_name, fieldsActual);
   }
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
@@ -1765,7 +1789,7 @@ void Frame_Glom::on_developer_dialog_hide()
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void Frame_Glom::on_connection_initialize_progress()
 {
-  Application *app = dynamic_cast<Application*>(Application::get_application());
+  AppWindow *app = dynamic_cast<AppWindow*>(AppWindow::get_appwindow());
   if(app)
     app->pulse_progress_message();
 }
@@ -1773,14 +1797,14 @@ void Frame_Glom::on_connection_initialize_progress()
 
 void Frame_Glom::on_connection_startup_progress()
 {
-  Application *app = dynamic_cast<Application*>(Application::get_application());
+  AppWindow *app = dynamic_cast<AppWindow*>(AppWindow::get_appwindow());
   if(app)
     app->pulse_progress_message();
 }
 
 void Frame_Glom::on_connection_cleanup_progress()
 {
-  Application *app = dynamic_cast<Application*>(Application::get_application());
+  AppWindow *app = dynamic_cast<AppWindow*>(AppWindow::get_appwindow());
   if(app)
     app->pulse_progress_message();
 }
@@ -2029,7 +2053,7 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
     }
     catch(const ExceptionConnection& ex)
     {
-      //g_warning("Frame_Glom::connection_request_password_and_choose_new_database_name(): caught exception.");
+      //std::cerr << G_STRFUNC << ": caught exception." << std::endl;
 
       if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_SERVER)
       {
@@ -2097,7 +2121,7 @@ void Frame_Glom::cleanup_connection()
 
 bool Frame_Glom::handle_request_password_connection_error(bool asked_for_password, const ExceptionConnection& ex, bool& database_not_found)
 {
-  g_warning("Frame_Glom::connection_request_password_and_attempt(): caught exception.");
+  std::cerr << G_STRFUNC << ": caught exception." << std::endl;
 
   //Initialize input parameter:
   database_not_found = false;
@@ -2147,7 +2171,7 @@ bool Frame_Glom::connection_request_password_and_attempt(bool& database_not_foun
     return false;
   }
 
-  Application* app = dynamic_cast<Application*>(get_app_window());
+  AppWindow* app = dynamic_cast<AppWindow*>(get_app_window());
   app->clear_progress_message();
 
   //Only ask for the password if we are shared on the network, or we are using a centrally hosted server.
@@ -2294,7 +2318,7 @@ void Frame_Glom::on_menu_report_selected(const Glib::ustring& report_name)
 
   FoundSet found_set = m_Notebook_Data.get_found_set();
 
-  ReportBuilder report_builder(Application::get_current_locale());
+  ReportBuilder report_builder(AppWindow::get_current_locale());
   report_builder.set_document(document);
   const std::string filepath = 
     report_builder.report_build_and_save(found_set, report); //TODO: Use found set's where_clause.
@@ -2322,9 +2346,12 @@ void Frame_Glom::do_print_layout(const Glib::ustring& print_layout_name, bool pr
     return;
   }
   
-  //TODO: When expandingt items, avoid the page gaps that the print layout's designed
+  //TODO: When expanding items, avoid the page gaps that the print layout's design
   //has added.  
-  const FoundSet found_set = m_Notebook_Data.get_found_set_details();
+  const FoundSet found_set = m_Notebook_Data.get_found_set_selected();
+  //Note that found_set.m_where_clause could be empty if there are no records yet,
+  //and that is acceptable if this is for a print preview while designing the print layout. 
+  
   PrintLayoutUtils::do_print_layout(print_layout, found_set, 
     preview, document, false /* do not avoid print margins */, transient_for);
 }
@@ -2347,7 +2374,7 @@ void Frame_Glom::on_dialog_layout_report_hide()
   }
 
   //Update the reports menu:
-  Application* pApp = dynamic_cast<Application*>(get_app_window());
+  AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
   if(pApp)
     pApp->fill_menu_reports(m_table_name);
 }
@@ -2366,8 +2393,8 @@ void Frame_Glom::on_dialog_layout_print_hide()
     document->set_print_layout(m_table_name, print_layout);
   }
 
-  //Update the reports menu:
-  Application* pApp = dynamic_cast<Application*>(get_app_window());
+  //Update the print layouts menu:
+  AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
   if(pApp)
     pApp->fill_menu_print_layouts(m_table_name);
 }
@@ -2384,7 +2411,7 @@ void Frame_Glom::on_dialog_tables_hide()
 #ifndef GLOM_ENABLE_CLIENT_ONLY
     if(document->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
     {
-      Application* pApp = dynamic_cast<Application*>(get_app_window());
+      AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
       if(pApp)
         pApp->fill_menu_tables();
 
@@ -2406,7 +2433,7 @@ void Frame_Glom::on_dialog_tables_hide()
 void Frame_Glom::on_notebook_data_switch_page(Gtk::Widget* /* page */, guint /* page_num */)
 {
   //Refill this menu, because it depends on whether list or details are visible:
-  Application* pApp = dynamic_cast<Application*>(get_app_window());
+  AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
   if(pApp)
     pApp->fill_menu_print_layouts(m_table_name);
 }
@@ -2417,6 +2444,18 @@ void Frame_Glom::on_notebook_data_record_details_requested(const Glib::ustring&
   show_table(table_name, primary_key_value);
 }
 
+void Frame_Glom::on_notebook_data_record_selection_changed()
+{
+  bool something_selected = false;
+  const FoundSet found_set = m_Notebook_Data.get_found_set_selected();
+  if(!found_set.m_where_clause.empty())
+    something_selected = true;
+  
+  AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
+  if(pApp)
+    pApp->enable_menu_print_layouts_details(something_selected);  
+}
+
 void Frame_Glom::update_records_count()
 {
   //Get the number of records available and the number found,
@@ -2462,11 +2501,6 @@ void Frame_Glom::on_button_find_all()
   show_table(m_table_name);
 }
 
-bool Frame_Glom::get_viewing_details() const
-{
-  return (m_Notebook_Data.get_current_view() == Notebook_Data::DATA_VIEW_Details);
-}
-
 Glib::ustring Frame_Glom::get_shown_table_name() const
 {
   return m_table_name;
