@@ -37,6 +37,7 @@
 #include <libglom/data_structure/report.h>
 #include <libglom/data_structure/print_layout.h>
 #include <libglom/data_structure/foundset.h>
+#include <libglom/data_structure/database_title.h>
 #include <libglom/appstate.h>
 #include <vector>
 #include <map>
@@ -213,7 +214,7 @@ public:
   
   
   typedef std::pair< sharedptr<LayoutItem_Field>, sharedptr<Relationship> > type_pairFieldTrigger;
-  typedef std::list<type_pairFieldTrigger> type_list_lookups;
+  typedef std::vector<type_pairFieldTrigger> type_list_lookups;
   
   /** Get the fields whose values should be looked up when @a field_name changes, with
    * the relationship used to lookup the value.
@@ -260,7 +261,7 @@ public:
   /// The translatable item and a hint about what it is.
   typedef std::pair< sharedptr<TranslatableItem>, Glib::ustring> pair_translatable_item_and_hint;
 
-  typedef std::list<pair_translatable_item_and_hint> type_list_translatables;
+  typedef std::vector<pair_translatable_item_and_hint> type_list_translatables;
   type_list_translatables get_translatable_items();
 
   static void fill_translatable_custom_choices(FieldFormatting& formatting, type_list_translatables& the_list, const Glib::ustring& hint);
@@ -278,7 +279,7 @@ public:
   ///When a relationship name is changed, change it in layouts and reports:
   void change_relationship_name(const Glib::ustring& table_name, const Glib::ustring& name, const Glib::ustring& name_new);
 
-  typedef std::list< sharedptr<TableInfo> > type_listTableInfo;
+  typedef std::vector< sharedptr<TableInfo> > type_listTableInfo;
   type_listTableInfo get_tables(bool plus_system_prefs = false) const;
   std::vector<Glib::ustring> get_table_names(bool plus_system_prefs = false) const;
 
@@ -320,8 +321,9 @@ public:
   Glib::ustring get_default_table() const;
   Glib::ustring get_first_table() const;
 
-  Glib::ustring get_database_title() const;
-  void set_database_title(const Glib::ustring& title);
+  Glib::ustring get_database_title_original() const;
+  Glib::ustring get_database_title(const Glib::ustring& locale) const;
+  void set_database_title_original(const Glib::ustring& title);
 
   std::vector<Glib::ustring> get_library_module_names() const;
   void set_library_module(const Glib::ustring& name, const Glib::ustring& script);
@@ -337,7 +339,7 @@ public:
   void set_startup_script(const Glib::ustring& script);
 
   /// These are only used when recreating a database from an example file. The actualy access-control is on the server, of course.
-  typedef std::list<GroupInfo> type_list_groups;
+  typedef std::vector<GroupInfo> type_list_groups;
   type_list_groups get_groups() const;
 
   /// This adds the group if necessary.
@@ -346,16 +348,14 @@ public:
   void remove_group(const Glib::ustring& group_name);
 
 
-  typedef std::list<Glib::ustring> type_listReports;
-  type_listReports get_report_names(const Glib::ustring& table_name) const;
+  std::vector<Glib::ustring> get_report_names(const Glib::ustring& table_name) const;
 
   void set_report(const Glib::ustring& table_name, const sharedptr<Report>& report);
   sharedptr<Report> get_report(const Glib::ustring& table_name, const Glib::ustring& report_name) const;
   void remove_report(const Glib::ustring& table_name, const Glib::ustring& report_name);
 
   //Print Layouts are precisely positioned layouts for printing to a printer:
-  typedef std::list<Glib::ustring> type_listPrintLayouts;
-  type_listPrintLayouts get_print_layout_names(const Glib::ustring& table_name) const;
+  std::vector<Glib::ustring> get_print_layout_names(const Glib::ustring& table_name) const;
   void set_print_layout(const Glib::ustring& table_name, const sharedptr<PrintLayout>& print_layout);
   sharedptr<PrintLayout> get_print_layout(const Glib::ustring& table_name, const Glib::ustring& print_layout_name) const;
   void remove_print_layout(const Glib::ustring& table_name, const Glib::ustring& print_layout_name);
@@ -503,7 +503,7 @@ private:
   void save_before_layout_item_formatting(xmlpp::Element* nodeItem, const FieldFormatting& format, Field::glom_field_type field_type = Field::TYPE_INVALID);
   void save_before_layout_item_formatting(xmlpp::Element* nodeItem, const sharedptr<const LayoutItem_WithFormatting>& layout_item);
 
-  void save_before_translations(xmlpp::Element* nodeItem, const TranslatableItem& item);
+  void save_before_translations(xmlpp::Element* nodeItem, const sharedptr<const TranslatableItem>& item);
   void save_before_print_layout_position(xmlpp::Element* nodeItem, const sharedptr<const LayoutItem>& item);
   void save_before_choicevalue(xmlpp::Element* nodeItem, const sharedptr<const ChoiceValue>& item, Field::glom_field_type field_type);
 
@@ -517,7 +517,7 @@ private:
   void load_after_layout_item_formatting(const xmlpp::Element* element, FieldFormatting& format, Field::glom_field_type field_type = Field::TYPE_INVALID, const Glib::ustring& table_name = Glib::ustring(), const Glib::ustring& field_name = Glib::ustring());
  void load_after_layout_item_formatting(const xmlpp::Element* element, const sharedptr<LayoutItem_WithFormatting>& layout_item, const Glib::ustring& table_name = Glib::ustring());
 
-  void load_after_translations(const xmlpp::Element* element, TranslatableItem& item);
+  void load_after_translations(const xmlpp::Element* element, const sharedptr<TranslatableItem>& item);
   void load_after_print_layout_position(const xmlpp::Element* nodeItem, const sharedptr<LayoutItem>& item);
   void load_after_choicevalue(const xmlpp::Element* element, const sharedptr<ChoiceValue>& item, Field::glom_field_type field_type);
 
@@ -621,7 +621,7 @@ private:
     type_vec_fields m_fields;
     type_vec_relationships m_relationships;
 
-    typedef std::list< LayoutInfo > type_layouts;
+    typedef std::vector< LayoutInfo > type_layouts;
     type_layouts m_layouts;
 
     typedef std::map< Glib::ustring, sharedptr<Report> > type_reports; //map of report names to reports
@@ -652,7 +652,7 @@ private:
   typedef std::map<Glib::ustring, GroupInfo> type_map_groups;
   type_map_groups m_groups;
 
-  Glib::ustring m_database_title;
+  sharedptr<DatabaseTitle> m_database_title;
   Glib::ustring m_translation_original_locale;
   std::vector<Glib::ustring> m_translation_available_locales; //Just a cache, based on other data.
 
