@@ -28,7 +28,7 @@
 #include <libglom/privs.h>
 #include <glom/python_embed/glom_python.h>
 #include <glom/python_embed/python_ui_callbacks.h>
-#include <glom/application.h>
+#include <glom/appwindow.h>
 #include <gtkmm/stock.h>
 #include <algorithm> //For std::find()
 #include <libglom/libglom_config.h>
@@ -352,27 +352,31 @@ Glib::ustring Box_Data::get_layout_name() const
 
 void Box_Data::execute_button_script(const sharedptr<const LayoutItem_Button>& layout_item, const Gnome::Gda::Value& primary_key_value)
 {
+  const Glib::ustring script = layout_item->get_script();
+  if(!Utils::script_check_for_pygtk2_with_warning(script, get_app_window()))
+    return;
+
   const sharedptr<Field> field_primary_key = get_field_primary_key();
   const type_map_fields field_values = get_record_field_values_for_calculation(m_table_name, field_primary_key, primary_key_value);
 
   //We need the connection when we run the script, so that the script may use it.
   sharedptr<SharedConnection> sharedconnection = connect_to_server(0 /* parent window */);
 
-    //Allow this UI to respond to UI change requests from the Python code:
-    AppPythonUICallbacks callbacks;
+  //Allow this UI to respond to UI change requests from the Python code:
+  AppPythonUICallbacks callbacks;
 
-    Glib::ustring error_message;
-    glom_execute_python_function_implementation(layout_item->get_script(),
-      field_values, //TODO: Maybe use the field's type here.
-      get_document(),
-      get_table_name(), field_primary_key, primary_key_value,
-      sharedconnection->get_gda_connection(),
-      callbacks,
-      error_message);
-    if(!error_message.empty())
-    {
-      std::cerr << "Python Error: " << error_message << std::endl;
-    }
+  Glib::ustring error_message;
+  glom_execute_python_function_implementation(script,
+    field_values, //TODO: Maybe use the field's type here.
+    get_document(),
+    get_table_name(), field_primary_key, primary_key_value,
+    sharedconnection->get_gda_connection(),
+    callbacks,
+    error_message);
+  if(!error_message.empty())
+  {
+    std::cerr << "Python Error: " << error_message << std::endl;
+  }
 }
 
 } //namespace Glom
