@@ -48,6 +48,8 @@ Box_Data_List::Box_Data_List()
   m_AddDel.signal_user_requested_edit().connect(sigc::mem_fun(*this, &Box_Data_List::on_adddel_user_requested_edit));
   m_AddDel.signal_script_button_clicked().connect(sigc::mem_fun(*this, &Box_Data_List::on_adddel_script_button_clicked));
   m_AddDel.signal_sort_clause_changed().connect(sigc::mem_fun(*this, &Box_Data_List::on_adddel_user_sort_clause_changed));
+  m_AddDel.signal_record_selection_changed().connect(
+    sigc::mem_fun(*this, &Box_Data_List::on_adddel_record_selection_changed));
 
   //TODO: Re-add this signal if this is really wanted, but make it part of a complete drag-and-drop feature for list views:
   //m_AddDel.signal_user_reordered_columns().connect(sigc::mem_fun(*this, &Box_Data_List::on_adddel_user_reordered_columns));
@@ -142,14 +144,13 @@ bool Box_Data_List::fill_from_database()
 
     enable_buttons();
 
+    m_AddDel.set_allow_view(table_privs.m_view);
     m_AddDel.set_found_set(m_found_set);
 
     result = m_AddDel.refresh_from_database();
 
     if(table_privs.m_view)
     {
-      //TODO: Don't show it if m_view is false.
-
       //Select first record:
       Glib::RefPtr<Gtk::TreeModel> refModel = m_AddDel.get_model();
       if(refModel)
@@ -447,6 +448,10 @@ void Box_Data_List::create_layout()
         child_item->set_editable(false);
 
       sharedptr<const LayoutItem_Field> child_field = sharedptr<const LayoutItem_Field>::cast_dynamic(child_item);
+
+      //This check has already happened in Frame_Glom::update_table_in_document_from_database().
+      //It is inefficient and unnecessary to do it here too.
+      /*
       if(child_field)
       {
         //Check that the field really exists, to avoid SQL errors.
@@ -457,6 +462,7 @@ void Box_Data_List::create_layout()
           continue;
         }
       }
+      */
 
       items_to_use.push_back(child_item);
     }
@@ -475,6 +481,9 @@ void Box_Data_List::create_layout()
     m_FieldsShown.push_back(layout_item); //TODO: Do this only if it is not already present.
   }
 
+  const Privileges table_privs = Privs::get_current_privs(m_found_set.m_table_name);
+  m_AddDel.set_allow_view(table_privs.m_view);
+    
   m_AddDel.set_found_set(m_found_set);
   m_AddDel.set_columns(items_to_use); //TODO: Use LayoutGroup::type_list_const_items instead?
 
@@ -535,6 +544,11 @@ void Box_Data_List::on_adddel_user_sort_clause_changed()
     document->set_criteria_current(m_table_name, m_found_set);
 }
 
+void Box_Data_List::on_adddel_record_selection_changed()
+{
+  m_signal_record_selection_changed.emit();
+}
+
 Gtk::TreeModel::iterator Box_Data_List::get_row_selected()
 {
   return m_AddDel.get_item_selected();
