@@ -20,9 +20,10 @@
 
 #include <glom/mode_data/box_data_list_related.h>
 #include <glom/mode_design/layout/dialog_layout_list_related.h>
-#include <glom/application.h>
+#include <glom/appwindow.h>
 #include <libglom/data_structure/glomconversions.h>
 #include <libglom/db_utils.h>
+#include <libglom/privs.h>
 #include <glom/glade_utils.h>
 #include <glom/frame_glom.h> //For show_ok_dialog()
 #include <glom/utils_ui.h> //For bold_message()).
@@ -82,6 +83,11 @@ bool Box_Data_List_Related::init_db_details(const Glib::ustring& parent_table, b
   else
     LayoutWidgetBase::m_table_name = Glib::ustring();
 
+  if(LayoutWidgetBase::m_table_name.empty())
+  {
+    std::cerr << G_STRFUNC << ": LayoutWidgetBase::m_table_name is null" << std::endl;
+  }
+  
   Base_DB_Table::m_table_name = LayoutWidgetBase::m_table_name;
 
   if(show_title)
@@ -123,8 +129,13 @@ bool Box_Data_List_Related::init_db_details(const Glib::ustring& parent_table, b
 
   enable_buttons();
 
+  //TODO: Use m_found_set?
   FoundSet found_set;
   found_set.m_table_name = LayoutWidgetBase::m_table_name;
+
+  const Privileges table_privs = Privs::get_current_privs(found_set.m_table_name);
+  m_AddDel.set_allow_view(table_privs.m_view);
+
   m_AddDel.set_found_set(found_set);
   return Box_Data_ManyRecords::init_db_details(found_set, "" /* layout_platform */); //Calls create_layout() and fill_from_database().
 }
@@ -165,6 +176,9 @@ bool Box_Data_List_Related::fill_from_database()
 
   m_AddDel.set_allow_add(allow_add);
 
+  const Privileges table_privs = Privs::get_current_privs(m_found_set.m_table_name);
+  m_AddDel.set_allow_view(table_privs.m_view);
+
   m_AddDel.set_found_set(m_found_set);
   result = m_AddDel.refresh_from_database();
 
@@ -278,7 +292,7 @@ void Box_Data_List_Related::on_adddel_record_added(const Gtk::TreeModel::iterato
   }
   else if(Conversions::value_is_empty(m_key_value))
   {
-    g_warning("Box_Data_List_Related::on_adddel_record_added(): m_key_value is NULL.");
+    std::cerr << G_STRFUNC << ": m_key_value is NULL." << std::endl;
   }
   else
   {
@@ -432,6 +446,10 @@ void Box_Data_List_Related::create_layout()
         child_item->set_editable(false);
 
       sharedptr<const LayoutItem_Field> child_field = sharedptr<const LayoutItem_Field>::cast_dynamic(child_item);
+      
+      //This check has already happened in Frame_Glom::update_table_in_document_from_database().
+      //It is inefficient and unnecessary to do it here too.
+      /*
       if(child_field)
       {
         //Check that the field really exists, to avoid SQL errors.
@@ -442,6 +460,7 @@ void Box_Data_List_Related::create_layout()
           continue;
         }
       }
+      */
 
       items_to_use.push_back(child_item);
     }
@@ -460,6 +479,9 @@ void Box_Data_List_Related::create_layout()
     items_to_use.push_back(layout_item);
   }
 
+  const Privileges table_privs = Privs::get_current_privs(m_found_set.m_table_name);
+  m_AddDel.set_allow_view(table_privs.m_view);
+  
   m_AddDel.set_found_set(m_found_set);
   m_AddDel.set_columns(items_to_use);
 
