@@ -20,7 +20,7 @@
 
 #include "buttonglom.h"
 #include <gtkmm/messagedialog.h>
-#include <glom/application.h>
+#include <glom/appwindow.h>
 #include <glom/glade_utils.h>
 #include <glom/utils_ui.h>
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -52,12 +52,12 @@ void ButtonGlom::init()
 
 }
 
-Application* ButtonGlom::get_application()
+AppWindow* ButtonGlom::get_appwindow()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
 
-  return dynamic_cast<Application*>(pWindow);
+  return dynamic_cast<AppWindow*>(pWindow);
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -84,7 +84,7 @@ void ButtonGlom::on_menu_properties_activate()
 
 bool ButtonGlom::on_button_press_event(GdkEventButton *event)
 {
-  Application* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
   if(pApp && pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
     GdkModifierType mods;
