@@ -21,8 +21,9 @@
 #include "combochoiceswithtreemodel.h"
 #include <glom/mode_data/datawidget/treemodel_db_withextratext.h>
 #include <libglom/data_structure/glomconversions.h>
+#include <libglom/privs.h>
 #include <glom/utils_ui.h>
-#include <glom/application.h>
+#include <glom/appwindow.h>
 #include <gtkmm/liststore.h>
 #include <glibmm/i18n.h>
 //#include <sstream> //For stringstream
@@ -274,7 +275,8 @@ void ComboChoicesWithTreeModel::set_choices_related(const Document* document, co
 
   //Set full field details, cloning the group to avoid the constness:
   sharedptr<LayoutGroup> layout_choice_extra_full = glom_sharedptr_clone(layout_choice_extra);
-  document->fill_layout_field_details(choice_relationship->get_to_table(), layout_choice_extra_full);
+  const Glib::ustring table_name = choice_relationship->get_to_table();
+  document->fill_layout_field_details(table_name,  layout_choice_extra_full);
 
   //Get the list of fields to show:
   LayoutGroup::type_list_items extra_fields;
@@ -285,6 +287,10 @@ void ComboChoicesWithTreeModel::set_choices_related(const Document* document, co
   layout_items.push_back(layout_choice_first);
   layout_items.insert(layout_items.end(), extra_fields.begin(), extra_fields.end());
 
+  //Make sure that the primary key is also in the list, but hidden,
+  //because TreeModel_DB needs it:
+  layout_items = Utils::get_layout_items_plus_primary_key(layout_items, document, table_name);
+
   //Build the FoundSet:
   const Glib::ustring to_table = choice_relationship->get_to_table();
   FoundSet found_set;
@@ -309,7 +315,9 @@ void ComboChoicesWithTreeModel::set_choices_related(const Document* document, co
 
   //We create DbTreeModelWithExtraText rather than just DbTreeModel, 
   //because Combo(has_entry) needs it.
-  m_refModel = DbTreeModelWithExtraText::create(found_set, layout_items, true /* allow_view */, false /* find mode */, m_db_layout_items);
+  //TODO: Avoid getting the actual data if the user does not have view rights.
+  const Privileges table_privs = Privs::get_current_privs(found_set.m_table_name);
+  m_refModel = DbTreeModelWithExtraText::create(found_set, layout_items, table_privs.m_view, false /* find mode */, m_db_layout_items);
   if(!m_refModel)
   {
     std::cerr << G_STRFUNC << ": DbTreeModel::create() returned a null model." << std::endl;
