@@ -19,13 +19,15 @@
  */
 
 #include "box_print_layouts.h"
-#include <glom/application.h>
+#include <glom/appwindow.h>
 #include <gtkmm/alignment.h>
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/stock.h>
 #include <libglom/utils.h> //For bold_message()).
 #include <glibmm/i18n.h>
 
+#include <iostream>
+
 namespace Glom
 {
 
@@ -113,7 +115,7 @@ bool Box_Print_Layouts::fill_from_database()
     }
    }
   else
-    g_warning("Box_Print_Layouts::fill_from_database(): document is null");
+    std::cerr << G_STRFUNC << ": document is null" << std::endl;
 
   //TODO:
 
@@ -141,7 +143,7 @@ void Box_Print_Layouts::on_adddel_user_added(const Gtk::TreeModel::iterator& row
       m_AddDel.set_value(row, m_colTitle, title);
     }
 
-    item->set_title(title, Application::get_current_locale());
+    item->set_title(title, AppWindow::get_current_locale());
 
     get_document()->set_print_layout(m_table_name, item);
   }
@@ -188,7 +190,7 @@ void Box_Print_Layouts::save_to_document()
         sharedptr<PrintLayout> item(new PrintLayout());
         item->set_name(name);
 
-        item->set_title( m_AddDel.get_value(iter, m_colTitle) , Application::get_current_locale()); //TODO: Translations: Store the original in the TreeView.
+        item->set_title( m_AddDel.get_value(iter, m_colTitle) , AppWindow::get_current_locale()); //TODO: Translations: Store the original in the TreeView.
 
         get_document()->set_print_layout(m_table_name, item);
         modified = true;
@@ -212,7 +214,7 @@ void Box_Print_Layouts::on_adddel_user_changed(const Gtk::TreeModel::iterator& r
     {
       if(column == m_colTitle)
       {
-        item->set_title( m_AddDel.get_value(row, m_colTitle) , Application::get_current_locale());
+        item->set_title( m_AddDel.get_value(row, m_colTitle) , AppWindow::get_current_locale());
         //TODO: Unnecessary:
         document->set_print_layout(m_table_name, item);
       }
