@@ -31,7 +31,7 @@
 #include <glom/utility_widgets/canvas/canvas_image_movable.h>
 #include <glom/utility_widgets/canvas/canvas_text_movable.h>
 #include <glom/print_layout/print_layout_utils.h>
-#include <glom/application.h>
+#include <glom/appwindow.h>
 #include <libglom/data_structure/glomconversions.h>
 #include <libglom/db_utils.h>
 
@@ -70,13 +70,13 @@ Canvas_PrintLayout::~Canvas_PrintLayout()
 {
 }
 
-void Canvas_PrintLayout::set_print_layout(const Glib::ustring& table_name, const sharedptr<const PrintLayout>& print_layout)
+void Canvas_PrintLayout::set_print_layout(const Glib::ustring& table_name, const sharedptr<PrintLayout>& print_layout)
 {
   m_table_name = table_name;
   m_modified = false;
 
   remove_all_items(m_items_group);
-  add_layout_group(print_layout->m_layout_group, true /* is top-level */);
+  add_layout_group(print_layout->get_layout_group(), true /* is top-level */);
 
   //Use the page setup:
   const Glib::ustring key_file_text = print_layout->get_page_setup();
@@ -121,7 +121,7 @@ void Canvas_PrintLayout::set_print_layout(const Glib::ustring& table_name, const
 sharedptr<PrintLayout> Canvas_PrintLayout::get_print_layout()
 {
   sharedptr<PrintLayout> result = sharedptr<PrintLayout>::create();
-  fill_layout_group(result->m_layout_group);
+  fill_layout_group(result->get_layout_group());
 
   //Page Setup:
   Glib::KeyFile key_file;
@@ -144,7 +144,9 @@ sharedptr<PrintLayout> Canvas_PrintLayout::get_print_layout()
 /*
 Glib::RefPtr<CanvasLayoutItem> Canvas_PrintLayout::create_canvas_item(const sharedptr<LayoutItem>& item)
 {
-  Glib::RefPtr<CanvasLayoutItem> result = CanvasLayoutItem::create(item);
+  Glib::RefPtr<CanvasLayoutItem> result = CanvasLayoutItem::create();
+  //TODO: Add to the canvas.
+  result->set_layout_item(item);
 
   return result;
 }
@@ -167,15 +169,22 @@ void Canvas_PrintLayout::add_layout_group_children(const sharedptr<LayoutGroup>&
     }
     else
     {
-      Glib::RefPtr<CanvasLayoutItem> canvas_item = CanvasLayoutItem::create(item);
-      if(canvas_item && canvas_item->get_child()) //get_child() returns null if the layout item was not handled.
-        add_canvas_layout_item(canvas_item);
+      create_canvas_layout_item_and_add(item);
     }
   }
 
   m_modified = true;
 }
 
+void Canvas_PrintLayout::create_canvas_layout_item_and_add(const sharedptr<LayoutItem>& layout_item)
+{
+  Glib::RefPtr<CanvasLayoutItem> canvas_item = CanvasLayoutItem::create();
+  add_canvas_layout_item(canvas_item);
+  canvas_item->set_layout_item(layout_item);
+  
+  canvas_item->set_outline_visible(m_outline_visibility);
+}
+
 void Canvas_PrintLayout::add_canvas_layout_item(const Glib::RefPtr<CanvasLayoutItem>& item)
 {
   if(!item)
@@ -193,7 +202,8 @@ void Canvas_PrintLayout::add_canvas_layout_item(const Glib::RefPtr<CanvasLayoutI
       item) );
 #endif //GLOM_ENABLE_CLIENT_ONLY
 
-   item->set_outline_visible(m_outline_visibility);
+   if(item->get_child())
+     item->set_outline_visible(m_outline_visibility);
 
    fill_with_data_system_preferences(item, get_document());
 }
@@ -213,9 +223,7 @@ void Canvas_PrintLayout::add_layout_group(const sharedptr<LayoutGroup>& group, b
   //Add the group item:
   if(!is_top_level)
   {
-    Glib::RefPtr<CanvasLayoutItem> canvas_item = CanvasLayoutItem::create(group);
-    if(canvas_item)
-      add_canvas_layout_item(canvas_item);
+    create_canvas_layout_item_and_add(group);
   }
 
   //Add the group's children.
@@ -709,6 +717,14 @@ guint Canvas_PrintLayout::get_page_count() const
 
 void Canvas_PrintLayout::fill_with_data(const FoundSet& found_set, bool avoid_page_margins)
 {
+  if(found_set.m_where_clause.empty())
+  {
+    //This might help a developer/debugger:
+    //This is not an error.
+    std::cout << G_STRFUNC << ": Not attempting to show real data because the where_clause is empty, maybe because there are no records in the database yet." << std::endl;
+    return;
+  }
+  
   fill_with_data(m_items_group, found_set, avoid_page_margins);
 }
 
