@@ -20,12 +20,19 @@
 
 #include "imageglom.h"
 #include <glibmm/i18n.h>
-#include <glom/application.h>
+#include <glom/appwindow.h>
 #include <glom/utils_ui.h>
 #include <glom/glade_utils.h>
 #include <libglom/data_structure/glomconversions.h>
 #include <glom/utility_widgets/dialog_image_load_progress.h>
 #include <glom/utility_widgets/dialog_image_save_progress.h>
+#include <gtkmm/appchooserdialog.h>
+#include <gtkmm/filechooserdialog.h>
+#include <gtkmm/stock.h>
+#include <giomm/file.h>
+#include <giomm/contenttype.h>
+#include <libgda/gda-blob-op.h>
+#include <glibmm/convert.h>
 
 #include <iostream>   // for cout, endl
 
@@ -101,8 +108,8 @@ bool ImageGlom::on_button_press_event(GdkEventButton *event)
   gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), event->device, 0, 0, &mods );
 
   //Enable/Disable items.
-  //We did this earlier, but get_application is more likely to work now:
-  Application* pApp = get_application();
+  //We did this earlier, but get_appwindow is more likely to work now:
+  AppWindow* pApp = get_appwindow();
   if(pApp)
   {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -150,12 +157,12 @@ bool ImageGlom::on_button_press_event(GdkEventButton *event)
   return Gtk::EventBox::on_button_press_event(event);
 }
 
-Application* ImageGlom::get_application()
+AppWindow* ImageGlom::get_appwindow()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
 
-  return dynamic_cast<Application*>(pWindow);
+  return dynamic_cast<AppWindow*>(pWindow);
 }
 
 bool ImageGlom::get_has_original_data() const
@@ -227,6 +234,12 @@ const GdaBinary* ImageGlom::get_binary() const
   const GdaBinary* gda_binary = 0;
   if(m_original_data.get_value_type() == GDA_TYPE_BINARY)
     gda_binary = gda_value_get_binary(m_original_data.gobj());
+  else if(m_original_data.get_value_type() == GDA_TYPE_BLOB)
+  {
+    const GdaBlob* gda_blob = gda_value_get_blob(m_original_data.gobj());
+    if(gda_blob && gda_blob_op_read_all(const_cast<GdaBlobOp*>(gda_blob->op), const_cast<GdaBlob*>(gda_blob)))
+      gda_binary = &(gda_blob->data);
+  }
   
   return gda_binary;
 }
@@ -482,7 +495,7 @@ void ImageGlom::on_menupopup_activate_open_file()
 
 void ImageGlom::on_menupopup_activate_open_file_with()
 {
-  Application* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
 
   //Offer the user a choice of suitable applications:
   const Glib::ustring mime_type = get_mime_type();
@@ -575,27 +588,11 @@ static void make_file_read_only(const Glib::ustring& uri)
 
 Glib::ustring ImageGlom::save_to_temp_file(bool show_progress)
 {
-  Glib::ustring uri;
-  
-  //Get a temporary file path:
-  std::string filepath;
-  try
+  Glib::ustring uri = Utils::get_temp_file_uri("glom_image");
+  if(uri.empty())
   {
-    const int filehandle = Glib::file_open_tmp(filepath);
-    ::close(filehandle);
+    std::cerr << ": uri is empty." << std::endl;
   }
-  catch(const Glib::Error& ex)
-  {
-    std::cerr << G_STRFUNC << ": Glib::file_open_tmp() failed" << std::endl;
-  }
-  
-  if(filepath.empty())
-  {
-    std::cerr << G_STRFUNC << ": Glib::file_open_tmp() returned an empty filepath" << std::endl;
-    return uri;
-  }
-  
-  uri = Glib::filename_to_uri(filepath);
   
   bool saved = false;
   if(show_progress)
@@ -674,7 +671,7 @@ static void set_file_filter_images(Gtk::FileChooser& file_chooser)
 
 void ImageGlom::on_menupopup_activate_save_file()
 {
-  Application* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
 
   Gtk::FileChooserDialog dialog(_("Save Image"), Gtk::FILE_CHOOSER_ACTION_SAVE);
   if(pApp)
@@ -740,7 +737,7 @@ bool ImageGlom::save_file(const Glib::ustring& uri)
   // Automatically delete the dialog when we no longer need it:
   std::auto_ptr<Gtk::Dialog> dialog_keeper(dialog_save);
 
-  Application* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
   if(pApp)
     dialog_save->set_transient_for(*pApp);
 
@@ -761,7 +758,7 @@ void ImageGlom::on_menupopup_activate_select_file()
   if(m_read_only)
     return;
     
-  Application* pApp = get_application();
+  AppWindow* pApp = get_appwindow();
 
   Gtk::FileChooserDialog dialog(_("Choose Image"), Gtk::FILE_CHOOSER_ACTION_OPEN);
   if(pApp)
